@@ -1,20 +1,8 @@
 //
 /* Copyright: before 2012: missing, see KMail copyrights
- * Copyright (C) 2012 Andras Mantia <amantia@kde.org> *
+ * SPDX-FileCopyrightText: 2012 Andras Mantia <amantia@kde.org> *
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 #include "filtermanager.h"
@@ -54,10 +42,6 @@ class FilterManager::Private
 public:
     Private(FilterManager *qq)
         : q(qq)
-        , mRequiredPartsBasedOnAll(SearchRule::Envelope)
-        , mTotalProgressCount(0)
-        , mCurrentProgressCount(0)
-        , mInboundFiltersExist(false)
     {
     }
 
@@ -74,10 +58,10 @@ public:
     void endFiltering(const Akonadi::Item &item) const;
     bool atLeastOneFilterAppliesTo(const QString &accountId) const;
     bool atLeastOneIncomingFilterAppliesTo(const QString &accountId) const;
-    FilterManager *q;
+    FilterManager *const q;
     QVector<MailCommon::MailFilter *> mFilters;
     QMap<QString, SearchRule::RequiredPart> mRequiredParts;
-    SearchRule::RequiredPart mRequiredPartsBasedOnAll;
+    SearchRule::RequiredPart mRequiredPartsBasedOnAll = SearchRule::Envelope;
     int mTotalProgressCount = 0;
     int mCurrentProgressCount = 0;
     bool mInboundFiltersExist = false;
@@ -376,7 +360,7 @@ void FilterManager::agentRemoved(const QString &identifier)
 
 void FilterManager::filter(const Akonadi::Item &item, FilterManager::FilterSet set, const QString &resourceId)
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    auto *job = new Akonadi::ItemFetchJob(item, this);
     job->setProperty("filterSet", static_cast<int>(set));
     job->setProperty("resourceId", resourceId);
     SearchRule::RequiredPart requestedPart = requiredPart(resourceId);
@@ -396,7 +380,7 @@ void FilterManager::filter(const Akonadi::Item &item, FilterManager::FilterSet s
 
 void FilterManager::filter(const Akonadi::Item &item, const QString &filterId, const QString &resourceId)
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    auto *job = new Akonadi::ItemFetchJob(item, this);
     job->setProperty("filterId", filterId);
 
     SearchRule::RequiredPart requestedPart = requiredPart(resourceId);
@@ -462,7 +446,7 @@ bool FilterManager::processContextItem(ItemContext context)
     const bool itemCanDelete = (col.rights() & Akonadi::Collection::CanDeleteItem);
     if (context.deleteItem()) {
         if (itemCanDelete) {
-            Akonadi::ItemDeleteJob *deleteJob = new Akonadi::ItemDeleteJob(context.item(), this);
+            auto *deleteJob = new Akonadi::ItemDeleteJob(context.item(), this);
             connect(deleteJob, &Akonadi::ItemDeleteJob::result, this, [this](KJob *job) {
                 d->deleteJobResult(job);
             });
@@ -487,7 +471,7 @@ bool FilterManager::processContextItem(ItemContext context)
             //remoteid still holds the old one. Without clearing it, we try to enforce that on the new location, which is
             //anything but good (and the server replies with "NO Only resources can modify remote identifiers"
             item.setRemoteId(QString());
-            Akonadi::ItemModifyJob *modifyJob = new Akonadi::ItemModifyJob(item, this);
+            auto *modifyJob = new Akonadi::ItemModifyJob(item, this);
             modifyJob->disableRevisionCheck(); //no conflict handling for mails as no other process could change the mail body and we don't care about flag conflicts
             //The below is a safety check to ignore modifying payloads if it was not requested,
             //as in that case we might change the payload to an invalid one
@@ -603,7 +587,7 @@ void FilterManager::applySpecificFilters(const Akonadi::Item::List &selectedMess
     d->mTotalProgressCount = selectedMessages.size();
     d->mCurrentProgressCount = 0;
 
-    Akonadi::ItemFetchJob *itemFetchJob = new Akonadi::ItemFetchJob(selectedMessages, this);
+    auto *itemFetchJob = new Akonadi::ItemFetchJob(selectedMessages, this);
     if (requiredPart == SearchRule::CompleteMessage) {
         itemFetchJob->fetchScope().fetchFullPayload(true);
     } else if (requiredPart == SearchRule::Header) {
@@ -631,7 +615,7 @@ void FilterManager::applyFilters(const Akonadi::Item::List &selectedMessages, Fi
     d->mTotalProgressCount = selectedMessages.size();
     d->mCurrentProgressCount = 0;
 
-    Akonadi::ItemFetchJob *itemFetchJob = new Akonadi::ItemFetchJob(selectedMessages, this);
+    auto *itemFetchJob = new Akonadi::ItemFetchJob(selectedMessages, this);
     SearchRule::RequiredPart requiredParts = requiredPart(QString());
     if (requiredParts == SearchRule::CompleteMessage) {
         itemFetchJob->fetchScope().fetchFullPayload(true);
