@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sendlaterjob.h"
@@ -54,7 +41,7 @@ void SendLaterJob::start()
     if (mInfo) {
         if (mInfo->itemId() > -1) {
             const Akonadi::Item item = Akonadi::Item(mInfo->itemId());
-            Akonadi::ItemFetchJob *fetch = new Akonadi::ItemFetchJob(item, this);
+            auto *fetch = new Akonadi::ItemFetchJob(item, this);
             mFetchScope.fetchAttribute<MailTransport::TransportAttribute>();
             mFetchScope.fetchAttribute<MailTransport::SentBehaviourAttribute>();
             mFetchScope.setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
@@ -113,7 +100,7 @@ void SendLaterJob::slotJobFinished(KJob *job)
             sendError(i18n("Cannot send message."), SendLaterManager::MailDispatchDoesntWork);
         } else {
             if (!mInfo->isRecurrence()) {
-                Akonadi::ItemDeleteJob *fetch = new Akonadi::ItemDeleteJob(mItem, this);
+                auto *fetch = new Akonadi::ItemDeleteJob(mItem, this);
                 connect(fetch, &Akonadi::ItemDeleteJob::result, this, &SendLaterJob::slotDeleteItem);
             } else {
                 sendDone();
