@@ -1,13 +1,10 @@
 /*
   This file is part of KTnef.
 
-  Copyright (C) 2002 Michael Goffioul <kdeprint@swing.be>
-  Copyright (c) 2012 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2002 Michael Goffioul <kdeprint@swing.be>
+  SPDX-FileCopyrightText: 2012 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  SPDX-License-Identifier: GPL-2.0-or-later
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
@@ -24,9 +21,7 @@
 #include <KTNEF/KTNEFParser>
 #include <KTNEF/KTNEFProperty>
 
-
 #include <KFileItemActions>
-#include <KService>
 #include <QAction>
 #include <KActionCollection>
 #include "ktnef_debug.h"
@@ -47,7 +42,6 @@
 
 #include <KRecentFilesAction>
 #include <KConfigGroup>
-#include <KRun>
 
 #include <QContextMenuEvent>
 #include <QDir>
@@ -254,7 +248,7 @@ void KTNEFMain::viewFile()
         } else {
             qCDebug(KTNEFAPPS_LOG) << "Mime type from attachment object: " << mimename;
         }
-        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, mimename);
+        auto *job = new KIO::OpenUrlJob(url, mimename);
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
         job->setDeleteTemporaryFile(true);
         job->start();
@@ -287,7 +281,11 @@ void KTNEFMain::viewFileAs()
         list.append(QUrl::fromLocalFile(extractTemp(mView->getSelection().at(0))));
 
         if (!list.isEmpty()) {
-            KRun::displayOpenWithDialog(list, this);
+            // Creating ApplicationLauncherJob without any args will invoke the open-with dialog
+            auto *job = new KIO::ApplicationLauncherJob();
+            job->setUrls(list);
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+            job->start();
         }
     } else {
         KMessageBox::information(
@@ -462,10 +460,10 @@ void KTNEFMain::viewDragRequested(const QList<KTnef::KTNEFAttach *> &list)
     }
 
     if (!list.isEmpty()) {
-        QMimeData *mimeData = new QMimeData;
+        auto *mimeData = new QMimeData;
         mimeData->setUrls(urlList);
 
-        QDrag *drag = new QDrag(this);
+        auto *drag = new QDrag(this);
         drag->setMimeData(mimeData);
     }
 }
@@ -549,7 +547,7 @@ void KTNEFMain::openWith(const KService::Ptr &offer)
         KTNEFAttach *attach = mView->getSelection().at(0);
         const QUrl url = QUrl::fromLocalFile(extractTemp(attach));
         const QList<QUrl> lst{url};
-        KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(offer);
+        auto *job = new KIO::ApplicationLauncherJob(offer);
         job->setUrls(lst);
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
         job->start();
@@ -565,7 +563,7 @@ QAction *KTNEFMain::createAppAction(const KService::Ptr &service, bool singleOff
         actionName = i18nc("@item:inmenu Open With, %1 is application name", "%1", actionName);
     }
 
-    QAction *act = new QAction(parent);
+    auto *act = new QAction(parent);
     act->setIcon(QIcon::fromTheme(service->icon()));
     act->setText(actionName);
     actionGroup->addAction(act);
@@ -584,7 +582,7 @@ void KTNEFMain::createOpenWithMenu(QMenu *topMenu)
     const KService::List offers = KFileItemActions::associatedApplications(QStringList() << mimename, QString());
     if (!offers.isEmpty()) {
         QMenu *menu = topMenu;
-        QActionGroup *actionGroup = new QActionGroup(menu);
+        auto *actionGroup = new QActionGroup(menu);
         connect(actionGroup, &QActionGroup::triggered, this, &KTNEFMain::slotOpenWithAction);
 
         if (offers.count() > 1) { // submenu 'open with'
@@ -609,12 +607,12 @@ void KTNEFMain::createOpenWithMenu(QMenu *topMenu)
         } else {
             openWithActionName = i18nc("@title:menu", "&Open With...");
         }
-        QAction *openWithAct = new QAction(menu);
+        auto *openWithAct = new QAction(menu);
         openWithAct->setText(openWithActionName);
         connect(openWithAct, &QAction::triggered, this, &KTNEFMain::viewFileAs);
         menu->addAction(openWithAct);
     } else { // no app offers -> Open With...
-        QAction *act = new QAction(topMenu);
+        auto *act = new QAction(topMenu);
         act->setText(i18nc("@title:menu", "&Open With..."));
         connect(act, &QAction::triggered, this, &KTNEFMain::viewFileAs);
         topMenu->addAction(act);
