@@ -1,13 +1,10 @@
 /*
   This file is part of KTnef.
 
-  Copyright (C) 2002 Michael Goffioul <kdeprint@swing.be>
-  Copyright (c) 2012 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2002 Michael Goffioul <kdeprint@swing.be>
+  SPDX-FileCopyrightText: 2012 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  SPDX-License-Identifier: GPL-2.0-or-later
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
@@ -42,7 +39,7 @@ int main(int argc, char *argv[])
                          QStringLiteral(KTNEF_VERSION),
                          i18n("Viewer for mail attachments using TNEF format"),
                          KAboutLicense::GPL,
-                         i18n("Copyright 2000 Michael Goffioul\nCopyright 2012  Allen Winter"));
+                         i18n("Copyright 2000 Michael Goffioul \nCopyright 2012  Allen Winter"));
 
     aboutData.addAuthor(
         i18n("Michael Goffioul"),
@@ -66,7 +63,7 @@ int main(int argc, char *argv[])
 
     KDBusService service;
 
-    KTNEFMain *tnef = new KTNEFMain();
+    auto *tnef = new KTNEFMain();
     tnef->show();
     const QStringList &args = parser.positionalArguments();
 
