@@ -1,22 +1,9 @@
 /*
-    Copyright (c) 2010 Casey Link <unnamedrambler@gmail.com>
-    Copyright (c) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-    Copyright (c) 2006-2008 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+    SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileCopyrightText: 2006-2008 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "configagentdelegate.h"
@@ -49,8 +36,8 @@ struct Icons {
     {
     }
 
-    QPixmap readyPixmap, syncPixmap, errorPixmap, offlinePixmap;
-    QIcon checkMailIcon;
+    const QPixmap readyPixmap, syncPixmap, errorPixmap, offlinePixmap;
+    const QIcon checkMailIcon;
 };
 
 Q_GLOBAL_STATIC(Icons, s_icons)
@@ -71,7 +58,7 @@ QTextDocument *ConfigAgentDelegate::document(const QStyleOptionViewItem &option,
     uint progress = index.model()->data(index, AgentInstanceModel::ProgressRole).toUInt();
     const QString statusMessage = index.model()->data(index, AgentInstanceModel::StatusMessageRole).toString();
 
-    QTextDocument *document = new QTextDocument(nullptr);
+    auto *document = new QTextDocument(nullptr);
 
     const QSize decorationSize(KIconLoader::global()->currentSize(KIconLoader::Desktop), KIconLoader::global()->currentSize(KIconLoader::Desktop));
     const QVariant data = index.model()->data(index, Qt::DecorationRole);
@@ -139,10 +126,10 @@ void ConfigAgentDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
     QPen pen = painter->pen();
 
-    QPalette::ColorGroup cg = (option.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
-    if (cg == QPalette::Normal && !(option.state & QStyle::State_Active)) {
-        cg = QPalette::Inactive;
-    }
+//    QPalette::ColorGroup cg = (option.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
+//    if (cg == QPalette::Normal && !(option.state & QStyle::State_Active)) {
+//        cg = QPalette::Inactive;
+//    }
 
     QStyleOptionViewItem opt(option);
     opt.showDecorationSelected = true;
@@ -166,7 +153,7 @@ QSize ConfigAgentDelegate::sizeHint(const QStyleOptionViewItem &option, const QM
     const int iconHeight = KIconLoader::global()->currentSize(KIconLoader::Desktop) + (s_delegatePaddingSize * 2);  //icon height + padding either side
     const int textHeight = option.fontMetrics.height() + qMax(option.fontMetrics.height(), 16) + (s_delegatePaddingSize * 2);   //height of text + icon/text + padding either side
 
-    return QSize(1, qMax(iconHeight, textHeight));    //any width,the view will give us the whole thing in list mode
+    return {1, qMax(iconHeight, textHeight)};    //any width,the view will give us the whole thing in list mode
 }
 
 QWidget *ConfigAgentDelegate::createEditor(QWidget *, const QStyleOptionViewItem &, const QModelIndex &) const
@@ -186,7 +173,7 @@ bool ConfigAgentDelegate::editorEvent(QEvent *event, QAbstractItemModel *model,
         return false;
     }
 
-    QMouseEvent *me = static_cast<QMouseEvent *>(event);
+    auto *me = static_cast<QMouseEvent *>(event);
     const QPoint mousePos = me->pos() - option.rect.topLeft();
 
     QStyleOptionButton buttonOpt = buttonOption(option);
