@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "configureappearancepage.h"
@@ -26,7 +15,6 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <Libkdepim/LineEditCatchReturnKey>
 #include "messagelistsettings.h"
 #include <MailCommon/TagWidget>
-#include "MailCommon/Tag"
 #include "kmkernel.h"
 
 #include "util.h"
@@ -91,38 +79,38 @@ AppearancePage::AppearancePage(QWidget *parent)
     //
     // "General" tab:
     //
-    ReaderTab *readerTab = new ReaderTab();
+    auto *readerTab = new ReaderTab();
     addTab(readerTab, i18n("General"));
     addConfig(MessageViewer::MessageViewerSettings::self(), readerTab);
 
     //
     // "Fonts" tab:
     //
-    FontsTab *fontsTab = new FontsTab();
+    auto *fontsTab = new FontsTab();
     addTab(fontsTab, i18n("Fonts"));
 
     //
     // "Colors" tab:
     //
-    ColorsTab *colorsTab = new ColorsTab();
+    auto *colorsTab = new ColorsTab();
     addTab(colorsTab, i18n("Colors"));
 
     //
     // "Layout" tab:
     //
-    LayoutTab *layoutTab = new LayoutTab();
+    auto *layoutTab = new LayoutTab();
     addTab(layoutTab, i18n("Layout"));
 
     //
     // "Headers" tab:
     //
-    HeadersTab *headersTab = new HeadersTab();
+    auto *headersTab = new HeadersTab();
     addTab(headersTab, i18n("Message List"));
 
     //
     // "Message Tag" tab:
     //
-    MessageTagTab *messageTagTab = new MessageTagTab();
+    auto *messageTagTab = new MessageTagTab();
     addTab(messageTagTab, i18n("Message Tags"));
 }
 
@@ -150,12 +138,11 @@ static const int numFontNames = sizeof fontNames / sizeof *fontNames;
 
 AppearancePageFontsTab::AppearancePageFontsTab(QWidget *parent)
     : ConfigModuleTab(parent)
-    , mActiveFontIndex(-1)
 {
     assert(numFontNames == sizeof mFont / sizeof *mFont);
 
     // "Use custom fonts" checkbox, followed by <hr>
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    auto *vlay = new QVBoxLayout(this);
     mCustomFontCheck = new QCheckBox(i18n("&Use custom fonts"), this);
     vlay->addWidget(mCustomFontCheck);
     vlay->addWidget(new KSeparator(Qt::Horizontal, this));
@@ -163,7 +150,7 @@ AppearancePageFontsTab::AppearancePageFontsTab(QWidget *parent)
             this, &ConfigModuleTab::slotEmitChanged);
 
     // "font location" combo box and label:
-    QHBoxLayout *hlay = new QHBoxLayout(); // inherites spacing
+    auto *hlay = new QHBoxLayout(); // inherites spacing
     vlay->addLayout(hlay);
     mFontLocationCombo = new QComboBox(this);
     mFontLocationCombo->setEnabled(false);   // !mCustomFontCheck->isChecked()
@@ -338,7 +325,7 @@ AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
     // "use custom colors" check box
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    auto *vlay = new QVBoxLayout(this);
     mCustomColorCheck = new QCheckBox(i18n("&Use custom colors"), this);
     vlay->addWidget(mCustomColorCheck);
     connect(mCustomColorCheck, &QCheckBox::stateChanged,
@@ -366,7 +353,7 @@ AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
             this, &ConfigModuleTab::slotEmitChanged);
 
     // close to quota threshold
-    QHBoxLayout *hbox = new QHBoxLayout();
+    auto *hbox = new QHBoxLayout();
     vlay->addLayout(hbox);
     QLabel *l = new QLabel(i18n("Close to quota threshold:"), this);
     hbox->addWidget(l);
@@ -485,7 +472,7 @@ QString AppearancePage::LayoutTab::helpAnchor() const
 AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    auto *vlay = new QVBoxLayout(this);
 
     // "folder list" radio buttons:
     populateButtonGroup(mFolderListGroupBox = new QGroupBox(this),
@@ -494,7 +481,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
     vlay->addWidget(mFolderListGroupBox);
     connect(mFolderListGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
 
-    QHBoxLayout *folderCBHLayout = new QHBoxLayout;
+    auto *folderCBHLayout = new QHBoxLayout;
     mFolderQuickSearchCB = new QCheckBox(i18n("Show folder quick search field"), this);
     connect(mFolderQuickSearchCB, &QAbstractButton::toggled, this, &ConfigModuleTab::slotEmitChanged);
     folderCBHLayout->addWidget(mFolderQuickSearchCB);
@@ -597,13 +584,12 @@ static const int numDateDisplayConfig
 
 AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
     : ConfigModuleTab(parent)
-    , mCustomDateFormatEdit(nullptr)
 {
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    auto *vlay = new QVBoxLayout(this);
 
     // "General Options" group:
     QGroupBox *group = new QGroupBox(i18nc("General options for the message list.", "General"), this);
-    QVBoxLayout *gvlay = new QVBoxLayout(group);
+    auto *gvlay = new QVBoxLayout(group);
 
     mDisplayMessageToolTips = new QCheckBox(
         MessageList::MessageListSettings::self()->messageToolTipEnabledItem()->label(), group);
@@ -620,9 +606,9 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
     aggregationLabel->setBuddy(mAggregationComboBox);
 
     using MessageList::Utils::AggregationConfigButton;
-    AggregationConfigButton *aggregationConfigButton = new AggregationConfigButton(group, mAggregationComboBox);
+    auto *aggregationConfigButton = new AggregationConfigButton(group, mAggregationComboBox);
 
-    QHBoxLayout *aggregationLayout = new QHBoxLayout();
+    auto *aggregationLayout = new QHBoxLayout();
     aggregationLayout->addWidget(aggregationLabel, 1);
     aggregationLayout->addWidget(mAggregationComboBox, 1);
     aggregationLayout->addWidget(aggregationConfigButton, 0);
@@ -641,9 +627,9 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
     themeLabel->setBuddy(mThemeComboBox);
 
     using MessageList::Utils::ThemeConfigButton;
-    ThemeConfigButton *themeConfigButton = new ThemeConfigButton(group, mThemeComboBox);
+    auto *themeConfigButton = new ThemeConfigButton(group, mThemeComboBox);
 
-    QHBoxLayout *themeLayout = new QHBoxLayout();
+    auto *themeLayout = new QHBoxLayout();
     themeLayout->addWidget(themeLabel, 1);
     themeLayout->addWidget(mThemeComboBox, 1);
     themeLayout->addWidget(themeConfigButton, 0);
@@ -673,9 +659,9 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
         }
         if (dateDisplayConfig[i].dateDisplay == DateFormatter::Custom) {
             QWidget *hbox = new QWidget(mDateDisplayBox);
-            QHBoxLayout *hboxHBoxLayout = new QHBoxLayout(hbox);
-            hboxHBoxLayout->setContentsMargins(0, 0, 0, 0);
-            QRadioButton *radio = new QRadioButton(buttonLabel, hbox);
+            auto *hboxHBoxLayout = new QHBoxLayout(hbox);
+            hboxHBoxLayout->setContentsMargins({});
+            auto *radio = new QRadioButton(buttonLabel, hbox);
             hboxHBoxLayout->addWidget(radio);
             mDateDisplay->addButton(radio, dateDisplayConfig[i].dateDisplay);
 
@@ -733,7 +719,7 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
             radio->setWhatsThis(mCustomDateWhatsThis);
             gvlay->addWidget(hbox);
         } else {
-            QRadioButton *radio = new QRadioButton(buttonLabel, mDateDisplayBox);
+            auto *radio = new QRadioButton(buttonLabel, mDateDisplayBox);
             gvlay->addWidget(radio);
             mDateDisplay->addButton(radio, dateDisplayConfig[i].dateDisplay);
         }
@@ -795,7 +781,7 @@ void AppearancePage::HeadersTab::doLoadFromGlobalSettings()
 
 void AppearancePage::HeadersTab::setDateDisplay(int num, const QString &format)
 {
-    DateFormatter::FormatType dateDisplay
+    auto dateDisplay
         = static_cast<DateFormatter::FormatType>(num);
 
     // special case: needs text for the line edit:
@@ -843,12 +829,12 @@ QString AppearancePage::ReaderTab::helpAnchor() const
 AppearancePageGeneralTab::AppearancePageGeneralTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    auto *topLayout = new QVBoxLayout(this);
 
     QGroupBox *readerBox = new QGroupBox(i18n("Message Window"), this);
     topLayout->addWidget(readerBox);
 
-    QVBoxLayout *readerBoxLayout = new QVBoxLayout(readerBox);
+    auto *readerBoxLayout = new QVBoxLayout(readerBox);
 
     // "Close message window after replying or forwarding" check box:
     populateCheckBox(mCloseAfterReplyOrForwardCheck = new QCheckBox(this),
@@ -867,7 +853,7 @@ AppearancePageGeneralTab::AppearancePageGeneralTab(QWidget *parent)
     QGroupBox *systrayBox = new QGroupBox(i18n("System Tray"), this);
     topLayout->addWidget(systrayBox);
 
-    QVBoxLayout *systrayBoxlayout = new QVBoxLayout(systrayBox);
+    auto *systrayBoxlayout = new QVBoxLayout(systrayBox);
 
     // "Enable system tray applet" check box
     mSystemTrayCheck = new QCheckBox(i18n("Enable system tray icon"), this);
@@ -941,8 +927,7 @@ TagListWidgetItem::TagListWidgetItem(const QIcon &icon, const QString &text, QLi
 }
 
 TagListWidgetItem::~TagListWidgetItem()
-{
-}
+= default;
 
 void TagListWidgetItem::setKMailTag(const MailCommon::Tag::Ptr &tag)
 {
@@ -958,17 +943,17 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
     mPreviousTag = -1;
-    QHBoxLayout *maingrid = new QHBoxLayout(this);
+    auto *maingrid = new QHBoxLayout(this);
 
     //Lefthand side Listbox and friends
 
     //Groupbox frame
     mTagsGroupBox = new QGroupBox(i18n("A&vailable Tags"), this);
     maingrid->addWidget(mTagsGroupBox);
-    QVBoxLayout *tageditgrid = new QVBoxLayout(mTagsGroupBox);
+    auto *tageditgrid = new QVBoxLayout(mTagsGroupBox);
 
     //Listbox, add, remove row
-    QHBoxLayout *addremovegrid = new QHBoxLayout();
+    auto *addremovegrid = new QHBoxLayout();
     tageditgrid->addLayout(addremovegrid);
 
     mTagAddLineEdit = new QLineEdit(mTagsGroupBox);
@@ -986,7 +971,7 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     addremovegrid->addWidget(mTagRemoveButton);
 
     //Up and down buttons
-    QHBoxLayout *updowngrid = new QHBoxLayout();
+    auto *updowngrid = new QHBoxLayout();
     tageditgrid->addLayout(updowngrid);
 
     mTagUpButton = new QPushButton(mTagsGroupBox);
@@ -1002,7 +987,7 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     updowngrid->addWidget(mTagDownButton);
 
     //Listbox for tag names
-    QHBoxLayout *listboxgrid = new QHBoxLayout();
+    auto *listboxgrid = new QHBoxLayout();
     tageditgrid->addLayout(listboxgrid);
     mTagListBox = new QListWidget(mTagsGroupBox);
     mTagListBox->setDragDropMode(QAbstractItemView::InternalMove);
@@ -1014,7 +999,7 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     //RHS for individual tag settings
 
     //Extra VBoxLayout for stretchers around settings
-    QVBoxLayout *tagsettinggrid = new QVBoxLayout();
+    auto *tagsettinggrid = new QVBoxLayout();
     maingrid->addLayout(tagsettinggrid);
 
     //Groupbox frame
@@ -1026,7 +1011,7 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
         actionCollections = kmkernel->getKMMainWidget()->actionCollections();
     }
 
-    QHBoxLayout *lay = new QHBoxLayout(mTagSettingGroupBox);
+    auto *lay = new QHBoxLayout(mTagSettingGroupBox);
     mTagWidget = new MailCommon::TagWidget(actionCollections, this);
     lay->addWidget(mTagWidget);
 
@@ -1066,8 +1051,7 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
 }
 
 AppearancePageMessageTagTab::~AppearancePageMessageTagTab()
-{
-}
+= default;
 
 void AppearancePage::MessageTagTab::slotEmitChangeCheck()
 {
@@ -1137,7 +1121,7 @@ void AppearancePage::MessageTagTab::slotRecordTagSettings(int aIndex)
         return;
     }
     QListWidgetItem *item = mTagListBox->item(aIndex);
-    TagListWidgetItem *tagItem = static_cast<TagListWidgetItem *>(item);
+    auto *tagItem = static_cast<TagListWidgetItem *>(item);
 
     MailCommon::Tag::Ptr tmp_desc = tagItem->kmailTag();
 
@@ -1162,7 +1146,7 @@ void AppearancePage::MessageTagTab::slotUpdateTagSettingWidgets(int aIndex)
     mTagUpButton->setEnabled((0 != aIndex));
     mTagDownButton->setEnabled(((int(mTagListBox->count()) - 1) != aIndex));
     QListWidgetItem *item = mTagListBox->currentItem();
-    TagListWidgetItem *tagItem = static_cast<TagListWidgetItem *>(item);
+    auto *tagItem = static_cast<TagListWidgetItem *>(item);
     MailCommon::Tag::Ptr tmp_desc = tagItem->kmailTag();
 
     disconnect(mTagWidget->tagNameLineEdit(), &QLineEdit::textChanged,
@@ -1205,7 +1189,7 @@ void AppearancePage::MessageTagTab::slotRemoveTag()
     if (tmp_index >= 0) {
         if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("Do you want to remove tag \'%1\'?", mTagListBox->item(mTagListBox->currentRow())->text()))) {
             QListWidgetItem *item = mTagListBox->takeItem(mTagListBox->currentRow());
-            TagListWidgetItem *tagItem = static_cast<TagListWidgetItem *>(item);
+            auto *tagItem = static_cast<TagListWidgetItem *>(item);
             MailCommon::Tag::Ptr tmp_desc = tagItem->kmailTag();
             if (tmp_desc->tag().isValid()) {
                 new Akonadi::TagDeleteJob(tmp_desc->tag());
@@ -1309,7 +1293,7 @@ void AppearancePage::MessageTagTab::doLoadFromGlobalSettings()
 {
     mTagListBox->clear();
 
-    Akonadi::TagFetchJob *fetchJob = new Akonadi::TagFetchJob(this);
+    auto *fetchJob = new Akonadi::TagFetchJob(this);
     fetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
     connect(fetchJob, &KJob::result, this, &AppearancePageMessageTagTab::slotTagsFetched);
 }
@@ -1320,7 +1304,7 @@ void AppearancePage::MessageTagTab::slotTagsFetched(KJob *job)
         qCWarning(KMAIL_LOG) << "Failed to load tags " << job->errorString();
         return;
     }
-    Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
 
     QList<MailCommon::TagPtr> msgTagList;
     const Akonadi::Tag::List tagList = fetchJob->tags();
@@ -1377,7 +1361,7 @@ void AppearancePage::MessageTagTab::save()
     slotRecordTagSettings(currentRow);
     const int numberOfMsgTagList = count;
     for (int i = 0; i < numberOfMsgTagList; ++i) {
-        TagListWidgetItem *tagItem = static_cast<TagListWidgetItem *>(mTagListBox->item(i));
+        auto *tagItem = static_cast<TagListWidgetItem *>(mTagListBox->item(i));
         if ((i >= mOriginalMsgTagList.count()) || *(tagItem->kmailTag()) != *(mOriginalMsgTagList[i])) {
             MailCommon::Tag::Ptr tag = tagItem->kmailTag();
             tag->priority = i;
