@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 #ifndef CONFIGUREAPPEARANCEPAGE_H
 #define CONFIGUREAPPEARANCEPAGE_H
@@ -46,7 +35,7 @@ class ThemeComboBox;
 
 namespace MailCommon {
 class Tag;
-typedef QSharedPointer<Tag> TagPtr;
+using TagPtr = QSharedPointer<Tag>;
 }
 
 namespace MailCommon {
@@ -64,7 +53,6 @@ public:
 private:
     void slotFontSelectorChanged(int);
     void doLoadOther() override;
-    void updateFontSelector();
     void doResetToDefaultsOther() override;
 
 private:
@@ -72,7 +60,7 @@ private:
     QComboBox *mFontLocationCombo = nullptr;
     KFontChooser *mFontChooser = nullptr;
 
-    int mActiveFontIndex;
+    int mActiveFontIndex{-1};
     QFont mFont[8];
 };
 
@@ -276,12 +264,12 @@ public:
     QString helpAnchor() const override;
 
     // hrmpf. moc doesn't like nested classes with slots/signals...:
-    typedef AppearancePageFontsTab FontsTab;
-    typedef AppearancePageColorsTab ColorsTab;
-    typedef AppearancePageLayoutTab LayoutTab;
-    typedef AppearancePageHeadersTab HeadersTab;
-    typedef AppearancePageGeneralTab ReaderTab;
-    typedef AppearancePageMessageTagTab MessageTagTab;
+    using FontsTab = AppearancePageFontsTab;
+    using ColorsTab = AppearancePageColorsTab;
+    using LayoutTab = AppearancePageLayoutTab;
+    using HeadersTab = AppearancePageHeadersTab;
+    using ReaderTab = AppearancePageGeneralTab;
+    using MessageTagTab = AppearancePageMessageTagTab;
 };
 
 #endif // CONFIGUREAPPEARANCEPAGE_H
