@@ -1,22 +1,10 @@
-/* Copyright 2009 Klarälvdalens Datakonsult AB
-   Copyright 2020 Laurent Montel <montel@kde.org>
+/*
+   SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB
+   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
+
 #include "archivefolderdialog.h"
 
 #include <MailCommon/BackupJob>
@@ -48,7 +36,7 @@ using namespace MailCommon;
 QString ArchiveFolderDialog::standardArchivePath(const QString &folderName)
 {
     QString currentPath = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
-    QDir dir(currentPath);
+    const QDir dir(currentPath);
     if (!dir.exists()) {
         currentPath = QDir::homePath();
     }
@@ -63,7 +51,7 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
 {
     setObjectName(QStringLiteral("archive_folder_dialog"));
     setWindowTitle(i18nc("@title:window for archiving a folder", "Archive Folder"));
-    QVBoxLayout *topLayout = new QVBoxLayout(this);
+    auto *topLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -75,8 +63,8 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
     QWidget *mainWidget = new QWidget(this);
     topLayout->addWidget(mainWidget);
     topLayout->addWidget(buttonBox);
-    QGridLayout *mainLayout = new QGridLayout(mainWidget);
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    auto *mainLayout = new QGridLayout(mainWidget);
+    mainLayout->setContentsMargins({});
 
     int row = 0;
 
@@ -190,7 +178,7 @@ void ArchiveFolderDialog::slotAccepted()
         return;
     }
 
-    MailCommon::BackupJob *backupJob = new MailCommon::BackupJob(mParentWidget);
+    auto *backupJob = new MailCommon::BackupJob(mParentWidget);
     backupJob->setRootFolder(mFolderRequester->collection());
     backupJob->setSaveLocation(mUrlRequester->url());
     backupJob->setArchiveType(static_cast<BackupJob::ArchiveType>(mFormatComboBox->currentIndex()));
