@@ -1,21 +1,9 @@
-/* Copyright 2009 Klarälvdalens Datakonsult AB
+/*
+   SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
+
 #ifndef ARCHIVEFOLDERDIALOG_H
 #define ARCHIVEFOLDERDIALOG_H
 
@@ -52,7 +40,7 @@ private:
     Q_REQUIRED_RESULT bool allowToDeleteFolders(const Akonadi::Collection &folder) const;
     Q_REQUIRED_RESULT QString standardArchivePath(const QString &folderName);
 
-    QWidget *mParentWidget = nullptr;
+    QWidget *const mParentWidget;
     QCheckBox *mDeleteCheckBox = nullptr;
     QCheckBox *mRecursiveCheckBox = nullptr;
     MailCommon::FolderRequester *mFolderRequester = nullptr;
