@@ -1,25 +1,13 @@
 /*
  * This file is part of KMail.
- * Copyright (c) 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
  *
- * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+ * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
  * Based on KMail code by:
- * Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
+ * SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef KMAIL_KMCOMPOSERWIN_H
@@ -34,18 +22,16 @@
 #include <QList>
 #include <QVector>
 
-// LIBKDEPIM includes
 #include <MessageComposer/RichTextComposerNg>
+#include <MessageComposer/ComposerViewBase>
 
 #include <MessageComposer/MessageSender>
 
-// KDEPIMLIBS includes
 #include <kmime/kmime_message.h>
 #include <kmime/kmime_headers.h>
 
 // Other includes
 #include <Libkleo/Enum>
-#include <MessageComposer/ComposerViewBase>
 
 class QUrl;
 
@@ -145,7 +131,7 @@ public Q_SLOTS:
 
     void addAttachmentsAndSend(const QList<QUrl> &urls, const QString &comment, int how) override;
 
-    void addAttachment(const QList<KMail::Composer::AttachmentInfo> &infos, bool showWarning) override;
+    void addAttachment(const QVector<KMail::Composer::AttachmentInfo> &infos, bool showWarning) override;
 
     void addAttachment(const QString &name, KMime::Headers::contentEncoding cte, const QString &charset, const QByteArray &data, const QByteArray &mimeType) override;
 
@@ -520,11 +506,6 @@ private:
     // helper method for rethinkFields
     int calcColumnWidth(int which, long allShowing, int width) const;
 
-    /** Initialize header fields. Should be called on new messages
-      if they are not set manually. E.g. before composing. Calling
-      of setAutomaticFields(), see below, is still required. */
-    void initHeader(KMime::Message *message, uint identity = 0);
-
     inline bool encryptToSelf() const;
 
 private:
@@ -546,8 +527,8 @@ private:
 
     void insertUrls(const QMimeData *source, const QList<QUrl> &urlList);
     void initializePluginActions();
-    Q_REQUIRED_RESULT bool showErrorMessage(KJob *job);
-    Q_REQUIRED_RESULT int validateLineWrapWidth();
+    bool showErrorMessage(KJob *job);
+    Q_REQUIRED_RESULT int validateLineWrapWidth() const;
     void slotSelectionChanged();
     void slotMessage(const QString &str);
     void slotEditorPluginInsertText(const QString &str);
@@ -573,8 +554,8 @@ private:
 
     KMime::Message::Ptr mMsg;
     QGridLayout *mGrid = nullptr;
-    QString mTextSelection;
-    QString mCustomTemplate;
+    const QString mTextSelection;
+    const QString mCustomTemplate;
     bool mLastSignActionState = false;
     bool mLastEncryptActionState = false;
     bool mSigningAndEncryptionExplicitlyDisabled = false;
@@ -588,7 +569,7 @@ private:
     QFont mBodyFont;
     QFont mFixedFont;
     uint mId = 0;
-    TemplateContext mContext = NoTemplate;
+    const TemplateContext mContext = NoTemplate;
 
     KRecentFilesAction *mRecentAction = nullptr;
 
