@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -36,8 +23,7 @@ CreateTaskJob::CreateTaskJob(const Akonadi::Item::List &items, QObject *parent)
 }
 
 CreateTaskJob::~CreateTaskJob()
-{
-}
+= default;
 
 void CreateTaskJob::start()
 {
@@ -50,7 +36,7 @@ void CreateTaskJob::start()
 
 void CreateTaskJob::fetchItems()
 {
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(mListItem, this);
+    auto *job = new Akonadi::ItemFetchJob(mListItem, this);
     job->fetchScope().fetchFullPayload(true);
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     job->fetchScope().fetchAttribute<TaskAttribute>();
@@ -65,7 +51,7 @@ void CreateTaskJob::itemFetchJobDone(KJob *job)
         deleteLater();
         return;
     }
-    Akonadi::ItemFetchJob *fetchjob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchjob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     const Akonadi::Item::List lst = fetchjob->items();
     if (lst.isEmpty()) {
         emitResult();
@@ -120,7 +106,7 @@ void CreateTaskJob::itemFetchJobDone(KJob *job)
     if (itemsToModify.isEmpty()) {
         slotModifyItemDone(nullptr);
     } else {
-        Akonadi::ItemModifyJob *modifyJob = new Akonadi::ItemModifyJob(itemsToModify, this);
+        auto *modifyJob = new Akonadi::ItemModifyJob(itemsToModify, this);
         modifyJob->disableRevisionCheck();
         modifyJob->setIgnorePayload(true);
         connect(modifyJob, &Akonadi::ItemModifyJob::result, this, &CreateTaskJob::slotModifyItemDone);
