@@ -1,22 +1,10 @@
 /*
     This file is part of KMail
 
-    Copyright (C) 1999 Waldo Bastian (bastian@kde.org)
-    Copyright (c) 2003 Zack Rusin <zack@kde.org>
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2003 Zack Rusin <zack@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    version 2 as published by the Free Software Foundation.
-
-    This software is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this library; see the file COPYING. If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef UNDOSTACK_H
@@ -36,8 +24,7 @@ class UndoInfo
 {
 public:
     UndoInfo()
-    {
-    }
+    = default;
 
     int id = -1;
     Akonadi::Item::List items;
@@ -73,7 +60,7 @@ private:
     Q_DISABLE_COPY(UndoStack)
     void slotMoveResult(KJob *);
     QList<UndoInfo *> mStack;
-    int mSize = 0;
+    const int mSize = 0;
     int mLastId = 0;
     UndoInfo *mCachedInfo = nullptr;
 };
